==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/UmowaParametrKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.TypParametruUmowa;
import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class UmowaParametrKey extends GenericDPSObject {
    /**
     * UMOWA_PARAMETR.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypParametruUmowa typ;

    /**
     * UMOWA_PARAMETR.UMOWA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long umowaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA_PARAMETR.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypParametruUmowa getTyp() {
        return typ;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * UMOWA_PARAMETR.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypParametruUmowa typ) {
        this.typ = typ;
    }

    /**
     * @return UMOWA_PARAMETR.UMOWA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getUmowaId() {
        return umowaId;
    }

    /**
     * UMOWA_PARAMETR.UMOWA_ID
     *
     * @param umowaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUmowaId(Long umowaId) {
        this.umowaId = umowaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UmowaParametrKey other = (UmowaParametrKey) that;
        return (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getUmowaId() == null ? other.getUmowaId() == null : this.getUmowaId().equals(other.getUmowaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getUmowaId() == null) ? 0 : getUmowaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", typ=").append(typ);
        sb.append(", umowaId=").append(umowaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/UmowaParametrKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.enums.TypParametruUmowa;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class UmowaParametrKey extends GenericDPSObject {
    /**
     * UMOWA_PARAMETR.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypParametruUmowa typ;

    /**
     * UMOWA_PARAMETR.UMOWA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long umowaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA_PARAMETR.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypParametruUmowa getTyp() {
        return typ;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * UMOWA_PARAMETR.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypParametruUmowa typ) {
        this.typ = typ;
    }

    /**
     * @return UMOWA_PARAMETR.UMOWA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getUmowaId() {
        return umowaId;
    }

    /**
     * UMOWA_PARAMETR.UMOWA_ID
     *
     * @param umowaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUmowaId(Long umowaId) {
        this.umowaId = umowaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UmowaParametrKey other = (UmowaParametrKey) that;
        return (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getUmowaId() == null ? other.getUmowaId() == null : this.getUmowaId().equals(other.getUmowaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getUmowaId() == null) ? 0 : getUmowaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", typ=").append(typ);
        sb.append(", umowaId=").append(umowaId);
        sb.append("]");
        return sb.toString();
    }
}
